==> py_roma-1.0-py3-none-any.whl: roma/__init__.py <==
# Copyright 2020 William Ro. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ======-=========================================================-=============
"""Gather all of the public Roma interfaces into this module."""

# ------------------------------------------------------------------------------
# Art
# ------------------------------------------------------------------------------
try:
  from .art import Easel
except:
  # Sometimes GUI support is not available
  print('! Warning: Failed to import `Easel` from `roma.art`.')

# ------------------------------------------------------------------------------
# Console
# ------------------------------------------------------------------------------
from .console.console import Console

console = Console(buffer_size=1000)

# ------------------------------------------------------------------------------
# Ideology
# ------------------------------------------------------------------------------
from .ideology.noear import Nomear

# ------------------------------------------------------------------------------
# SPQR
# ------------------------------------------------------------------------------
from .spqr.arguments import Arguments
from .spqr import atticus
from .spqr import censor
from .spqr import finder
from .spqr import wizard

from .spqr.censor import check_type
from .spqr.table import Table

# ------------------------------------------------------------------------------
# Mercurius
# ------------------------------------------------------------------------------
from .mercurius.city import City
from .mercurius import io

==> py_roma-1.0.0.dev5-py3-none-any.whl: roma/__init__.py <==
# Copyright 2020 William Ro. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ======-=========================================================-=============
"""Gather all of the public Roma interfaces into this module."""

# ------------------------------------------------------------------------------
# Console
# ------------------------------------------------------------------------------
from .console.console import Console

console = Console(buffer_size=1000)

# ------------------------------------------------------------------------------
# Console
# ------------------------------------------------------------------------------
from .via.city import City

# ------------------------------------------------------------------------------
# Ideology
# ------------------------------------------------------------------------------
from .ideology.noear import Nomear

# ------------------------------------------------------------------------------
# SPQR
# ------------------------------------------------------------------------------
from .spqr.arguments import Arguments
from .spqr import atticus
from .spqr import censor
from .spqr import finder
from .spqr import wizard

from .spqr.censor import check_type
